=====================
Configuration Options
=====================

The following is an overview of all available configuration options in
Masakari. For a sample configuration file, refer to :doc:`sample_config`.

.. show-options::
   :config-file: etc/masakari/masakari-config-generator.conf
